=======
EOVSAPY
=======
|Latest Version|

.. |Latest Version| image:: https://img.shields.io/pypi/v/eovsapy.svg
   :target: https://pypi.python.org/pypi/eovsapy/

Python code and files for Expanded Owens Valley Solar Array. Our homepage `EOVSAPY`_ has more information about the project.

.. _EOVSAPY: https://github.com/suncasa/eovsapy


Installation
============
The recommended way to install EOVSAPY is with `pip`_.
Once pip is installed, run the following command:

.. code:: bash

    $ pip install eovsapy

.. _pip: https://packaging.python.org/tutorials/installing-packages/




